@@ -7,13 +7,13 @@
 #ifndef CONFIGURE_DIALOG_H
 #define CONFIGURE_DIALOG_H
 
-#include <QAbstractButton>
-#include <QCloseEvent>
 #include <KPageDialog>
 
 class PrinterPage;
 class ModifyPrinter;
 class PrinterOptions;
+class QAbstractButton;
+class QCloseEvent;
 
 class Q_DECL_EXPORT ConfigureDialog : public KPageDialog
 {
@@ -25,7 +25,7 @@ public:
 private:
     void currentPageChangedSlot(KPageWidgetItem *current, KPageWidgetItem *before);
     void enableButtonApply(bool enable);
-    void slotButtonClicked(QAbstractButton * pressedButton);
+    void slotButtonClicked(QAbstractButton *pressedButton);
     void ppdChanged();
 
     ModifyPrinter *modifyPrinter = nullptr;
